==> q3-ui-repeater-4.5.2.tgz: package/lib/components/ItemHeader/ItemHeader.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _q3UiExports = require("q3-ui-exports");

var _Avatar = _interopRequireDefault(require("@material-ui/core/Avatar"));

var _Typography = _interopRequireDefault(require("@material-ui/core/Typography"));

var _ItemHeader = _interopRequireDefault(require("./ItemHeader"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

jest.mock('../useStyle', () => jest.fn().mockReturnValue({}));

const getItemHeader = props => global.shallow( /*#__PURE__*/_react.default.createElement(_ItemHeader.default, _extends({
  item: {
    id: '1'
  },
  isIn: jest.fn(),
  save: jest.fn(),
  title: "Foo"
}, props)));

beforeAll(() => {
  jest.spyOn(_react.default, 'useContext').mockReturnValue({
    isChecked: jest.fn()
  });
});
describe('ItemHeader', () => {
  it('should render SelectOne', () => expect(getItemHeader({
    showMultiselect: true
  }).find(_q3UiExports.SelectOne)).toHaveLength(1));
  it('should not render SelectOne', () => expect(getItemHeader({
    showMultiselect: false
  }).find(_q3UiExports.SelectOne)).toHaveLength(0));
  it('should render photo', () => expect(getItemHeader({
    photo: 'https://google.ca'
  }).find(_Avatar.default)).toHaveLength(1));
  it('should not render photo', () => expect(getItemHeader().find(_Avatar.default)).toHaveLength(0));
  it('should render description', () => expect(getItemHeader({
    description: 'Foo'
  }).find(_Typography.default)).toHaveLength(1));
  it('should not render description', () => expect(getItemHeader().find(_Typography.default)).toHaveLength(0));
});

==> q3-ui-repeater-4.5.15.tgz: package/lib/components/ItemHeader/ItemHeader.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));
var _q3UiExports = require("q3-ui-exports");
var _Avatar = _interopRequireDefault(require("@material-ui/core/Avatar"));
var _Typography = _interopRequireDefault(require("@material-ui/core/Typography"));
var _ItemHeader = _interopRequireDefault(require("./ItemHeader"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
jest.mock('../useStyle', () => jest.fn().mockReturnValue({}));
const getItemHeader = props => global.shallow( /*#__PURE__*/_react.default.createElement(_ItemHeader.default, _extends({
  item: {
    id: '1'
  },
  isIn: jest.fn(),
  save: jest.fn(),
  title: "Foo"
}, props)));
beforeAll(() => {
  jest.spyOn(_react.default, 'useContext').mockReturnValue({
    isChecked: jest.fn()
  });
});
describe('ItemHeader', () => {
  it('should render SelectOne', () => expect(getItemHeader({
    showMultiselect: true
  }).find(_q3UiExports.SelectOne)).toHaveLength(1));
  it('should not render SelectOne', () => expect(getItemHeader({
    showMultiselect: false
  }).find(_q3UiExports.SelectOne)).toHaveLength(0));
  it('should render photo', () => expect(getItemHeader({
    photo: 'https://google.ca'
  }).find(_Avatar.default)).toHaveLength(1));
  it('should not render photo', () => expect(getItemHeader().find(_Avatar.default)).toHaveLength(0));
  it('should render description', () => expect(getItemHeader({
    description: 'Foo'
  }).find(_Typography.default)).toHaveLength(1));
  it('should not render description', () => expect(getItemHeader().find(_Typography.default)).toHaveLength(0));
});
